# Homonculi

This project is meant for running quizzes through an LLM. We ask the LLM to take the quiz, grade them, and ask them to evaluate whether they agree with the feedback. This is mostly to help us identify issues in exams before we deploy them.
